@@ -6,7 +6,7 @@ from importlib import import_module, metadata
 from os.path import dirname, basename, join
 from pathlib import Path
 from types import ModuleType
-from typing import Optional, Union, Callable, Iterable, Dict, Tuple, List
+from typing import Optional, Union, Callable, Iterable, Dict, Tuple, List, TypedDict
 
 import ptyx.randfunc as randfunc
 from ptyx import __version__, __api__
@@ -17,6 +17,16 @@ from ptyx.syntax_tree import Node, SyntaxTreeGenerator, Tag, TagSyntax
 from ptyx.utilities import advanced_split, numbers_to_floats, _float_me_if_you_can
 
 
+class State(TypedDict, total=False):
+    syntax_tree: Node
+    seed: Optional[int]
+    input: str
+    path: Optional[Path]
+    loaded_extensions: dict[str, ModuleType]
+    plain_ptyx_code: str
+    after_include: Optional[str]
+
+
 # =============================================================================
 # #ASSERT{}
 # #CASE{int}...#CASE{int}...#END
@@ -801,18 +811,17 @@ class Compiler:
         self.latex_generator = LatexGenerator(self)
         self.reset()
 
-    def reset(self):
-        self._state = {}
-        self._new_closing_tags = set()
+    def reset(self) -> None:
+        self._state: State = {}
         # Make SyntaxTreeGenerator context free ?
         self.syntax_tree_generator.reset()
 
-    def read_code(self, code: str):
+    def read_code(self, code: str) -> None:
         """Feed compiler with given code."""
         self._state["path"] = None
         self._state["input"] = code
 
-    def read_file(self, path: Union[Path, str]):
+    def read_file(self, path: Union[Path, str]) -> None:
         """Feed compiler with given file code."""
         self._state["path"] = Path(path).expanduser().resolve()
         with open(path, "r") as input_file:
@@ -833,8 +842,8 @@ class Compiler:
             path = self.dir_path / path
         return path
 
-    def _include_subfiles(self, code: str):
-        """Parse all #INCLUDE tags, then include subfiles content."""
+    def _include_subfiles(self, code: str) -> str:
+        """Parse all #INCLUDE tags, then include corresponding files content."""
 
         def include(match):
             path = self._resolve_path(match.group(1))
@@ -844,7 +853,7 @@ class Compiler:
         # noinspection RegExpRedundantEscape
         return re.sub(r"#INCLUDE\{([^}]+)\}", include, code)
 
-    def _call_extensions(self, code: str):
+    def _call_extensions(self, code: str) -> tuple[str, dict[str, ModuleType]]:
         """Search for extensions (#LOAD{name} tags), then call them."""
         # First, we search if some extensions must be load.
         # This must be done at the very beginning, since extensions may
@@ -906,8 +915,11 @@ class Compiler:
                 code = extensions[name].main(code, self)
         return code, extensions
 
-    def _read_seed(self, code: str):
-        """Extract seed value from code, searching for #SEED{num} tag."""
+    def _read_seed(self, code: str) -> Tuple[str, Optional[int]]:
+        """Extract seed value from code, searching for #SEED{num} tag.
+
+        Return the code without the #SEED{...} tag, and the seed value (if any, `None` else).
+        """
         counter = 0
         value = None
 
@@ -927,15 +939,17 @@ class Compiler:
             print(f"Warning: multiple #SEED found, only last one will be used: {value}.")
         return code, value
 
-    def preparse(self):
+    def preparse(self) -> None:
         code = self._state.get("input")
         if code is None:
             raise RuntimeError("Compiler.read_code() or Compiler.read_file() must be run first.")
         remove_comments = self.syntax_tree_generator.remove_comments
         # Remove comments first, so one can comment a file inclusion for example.
         code = remove_comments(code)
+        assert isinstance(code, str)
         code = remove_comments(self._include_subfiles(code))
         self._state["after_include"] = code
+        assert isinstance(code, str)
         code, extensions = self._call_extensions(code)
         code, seed = self._read_seed(code)
         self._state["plain_ptyx_code"] = code
@@ -960,16 +974,20 @@ class Compiler:
                 with open(filename, "w") as f:
                     f.write(code)
 
-    def generate_syntax_tree(self):
+    def generate_syntax_tree(self) -> None:
         code = self._state.get("plain_ptyx_code")
         if code is None:
             raise RuntimeError("Compiler.preparse() must be run first.")
         self._state["syntax_tree"] = self.syntax_tree_generator.generate_tree(code)
 
-    def get_latex(self, **context):
+    def get_latex(self, **context) -> str:
+        """Compile pTyX code and return LaTeX code.
+
+        `Compiler.generate_syntax_tree()` must be run first.
+        """
         tree = self._state.get("syntax_tree")
         if tree is None:
-            raise RuntimeError("Compiler.generate_syntax_tree() must be run first.")
+            raise RuntimeError("`Compiler.generate_syntax_tree()` must be run first.")
         gen = self.latex_generator
         gen.clear()
         gen.context.update(context)
@@ -992,7 +1010,7 @@ class Compiler:
             print("Warning: no API version specified. This may be an old pTyX file.")
         return latex
 
-    def add_new_tags(self, *tags: Tuple[str, Tuple]):
+    def add_new_tags(self, *tags: Tuple[str, Tuple]) -> None:
         """Add ability for extensions to extend syntax, adding new tags."""
         for name, syntax in tags:
             self.syntax_tree_generator.tags[name] = syntax
@@ -1018,11 +1036,11 @@ class Compiler:
         return self._state["syntax_tree"]
 
     @property
-    def seed(self):
+    def seed(self) -> Optional[int]:
         return self._state["seed"]
 
     @property
-    def file_path(self):
+    def file_path(self) -> Optional[Path]:
         return self._state["path"]
 
     @property
