@@ -2,7 +2,7 @@ import random
 import functools
 from collections import namedtuple
 from math import gcd
-from typing import Callable
+from typing import Callable, Iterable
 
 from numpy import array
 
@@ -69,10 +69,17 @@ def set_seed(value):
 
 
 @sandboxed
-def randint(a=None, b=None, exclude=(), maximum=100000):
+def randint(a: int = None, b: int = None, exclude: Iterable = ()) -> int:
+    """Generate a random integer between `a` and `b`.
+
+    Forbidden values may be specified using `exclude` argument.
+    """
+    if a is None and b is not None:
+        a, b = b, a
     if b is None:
         b = 9 if a is None else a
         a = 2
+    assert a is not None and b is not None
     while a in exclude:
         a += 1
         if a > b:
@@ -91,13 +98,19 @@ def randint(a=None, b=None, exclude=(), maximum=100000):
 
 
 @sandboxed
-def srandint(a=None, b=None, exclude=(), maximum=100000):
+def srandint(a: int = None, b: int = None, exclude: Iterable = ()) -> int:
+    """Generate a random integer between `a` and `b` or between `-b` and `-a`.
+
+    `a` and `b` should be positive integers.
+    Forbidden values may be specified using `exclude` argument.
+    """
     if a is None and b is None:
         a, b = 2, 9
     elif a is None:
         a = 2
     elif b is None:
         a, b = 2, a
+    assert a is not None and b is not None
     # pylint: disable=invalid-unary-operand-type
     while a in exclude and -a in exclude:
         a += 1
@@ -144,12 +157,15 @@ def srandpoint(a=None, b=None, exclude=()):
             return Point(x, y)
 
 
-def is_mult_2_5(val):
-    """Test if integer val matches 2^n*5^m."""
+def is_mult_2_5(val: int | Iterable[int]) -> bool:
+    """Test if integer `val` matches 2**n * 5**m.
+
+    `val` may also be a list (or other iterable) of integers,
+     in that case all values must match 2**n * 5**m.
+    """
+    ints: tuple[type, ...] = (int, )
     if sympy:
-        ints = (sympy.Integer, int)
-    else:
-        ints = (int,)
+        ints += (sympy.Integer, )
     if hasattr(val, "__iter__"):
         return all(is_mult_2_5(v) for v in val)
     if val == 0 or not isinstance(val, ints):
@@ -165,6 +181,8 @@ def is_mult_2_5(val):
 def randfrac(a=None, b=None, exclude=(), not_decimal=False, den=None):
     """Return a random positive fraction which is never an integer.
 
+    By default, numerator and denominators are random integers between `a` and `b`.
+
     Use `den` to specify denominator value; `den` must be an integer or
     a list of integers.
     """
@@ -290,7 +308,7 @@ def randmatrix(size=(3, 3), rank=None, unique=False, func=srandint, **kw):
     """Return a matrix of dimensions `size` (number of lines, number of columns).
 
     `func` is used to build the random values, and **kw are passed to it.
-    Be carrefull with `rank`, as it may induce infinite recursion if
+    Be careful with `rank`, as it may induce infinite recursion if
     condition can't be satisfied.
 
     Set `unique` to True if each coefficient must be unique.
@@ -305,6 +323,7 @@ def randmatrix(size=(3, 3), rank=None, unique=False, func=srandint, **kw):
         raise ValueError("Matrix rank can't exceed lines nor columns number.")
     else:
         while True:
+            # noinspection PyUnusedLocal
             matrix = [[func(**kw) for j in range(size[1])] for i in range(rank)]
             if Matrix(matrix).rank() == rank:
                 break
