@@ -151,6 +151,12 @@ class PtyxArgumentParser(argparse.ArgumentParser):
             action="store_true",
             help="Generate a batch file for printing all pdf files using SumatraPDF.",
         )
+        self.add_argument(
+            "--cpu-cores",
+            type=int,
+            metavar="N_CORES",
+            help="Number of cpu cores to use when compiling. (Automatically detected by default).",
+        )
         self.add_argument(
             "--context",
             default="",
